Assert in contract asserts that the contract is currently executing within a
contract. The macro maps to code when testutils are enabled or in tests,
otherwise maps to nothing.
Wrapper for a Val that is tagged with [Tag::Error], interpreting the
Val’s body as a pair of a 28-bit error-type code and a 32-bit error
code. The error-type codes correspond to the enumerated cases of
ScErrorType, and the error codes correspond to the code values stored in
each variant of the ScError union.
MuxedAddress is a union type that represents either the regular Address,
or a ‘multiplexed’ address that consists of a regular address and a u64 id
and can be used for representing the ‘virtual’ accounts that allows for
managing multiple balances off-chain with only a single on-chain balance
entry. The address part can be used as a regular Address, and the id
part should be used only in the events for the off-chain processing.
An expanded form of a Symbol that stores its characters as ASCII-range
bytes in a u8 array – up to the maximum size of a large symbol object –
rather than as packed 6-bit codes within a u64. Useful for interoperation
with standard Rust string types.
Trait for types that can be fallibly converted to another type V, analogous
to the standard Rust type TryFrom, but making use of the provided Env
implementation E in order to convert parts of the type that require it.
Mainly this exists because Val types that contain object handles need to
delegate to the environment to look up and extract the content of those
handles.
The opposite trait to TryFromVal, analogous to the way that TryInto
exists as an opposite to TryFrom. Exists only for convenience of doing
conversions via .try_into_val(e) or specifying convertability with a bound
like TryIntoVal<E,Other>.