TokenFnSpec

Struct TokenFnSpec 

pub struct TokenFnSpec;

Implementations

Source

impl TokenFnSpec

pub const fn spec_xdr_allowance() -> [u8; 468]

Returns the allowance for spender to transfer from from.

The amount returned is the amount that spender is allowed to transfer out of from’s balance. When the spender transfers amounts, the allowance will be reduced by the amount transferred.

Arguments
  • from - The address holding the balance of tokens to be drawn from.
  • spender - The address spending the tokens held by from.
Source

impl TokenFnSpec

pub const fn spec_xdr_approve() -> [u8; 1044]

Set the allowance by amount for spender to transfer/burn from from.

The amount set is the amount that spender is approved to transfer out of from’s balance. The spender will be allowed to transfer amounts, and when an amount is transferred the allowance will be reduced by the amount transferred.

Arguments
  • from - The address holding the balance of tokens to be drawn from.
  • spender - The address being authorized to spend the tokens held by from.
  • amount - The tokens to be made available to spender.
  • expiration_ledger - The ledger number where this allowance expires. Cannot be less than the current ledger number unless the amount is being set to 0. An expired entry (where expiration_ledger < the current ledger number) should be treated as a 0 amount allowance.
Events

Emits an event with topics ["approve", from: Address, spender: Address], data = [amount: i128, expiration_ledger: u32]

Source

impl TokenFnSpec

pub const fn spec_xdr_balance() -> [u8; 200]

Returns the balance of id.

Arguments
  • id - The address for which a balance is being queried. If the address has no existing balance, returns 0.
Source

impl TokenFnSpec

pub const fn spec_xdr_transfer() -> [u8; 596]

Transfer amount from from to to.

Arguments
  • from - The address holding the balance of tokens which will be withdrawn from.
  • to - The address which will receive the transferred tokens.
  • amount - The amount of tokens to be transferred.
Events

Emits an event with:

  • topics ["transfer", from: Address, to: Address]
  • data { to_muxed_id: Option<u64>, amount: i128 }: Map

Legacy implementations may emit an event with:

  • topics ["transfer", from: Address, to: Address]
  • data amount: i128
Source

impl TokenFnSpec

pub const fn spec_xdr_transfer_from() -> [u8; 928]

Transfer amount from from to to, consuming the allowance that spender has on from’s balance. Authorized by spender (spender.require_auth()).

The spender will be allowed to transfer the amount from from’s balance if the amount is less than or equal to the allowance that the spender has on the from’s balance. The spender’s allowance on from’s balance will be reduced by the amount.

Arguments
  • spender - The address authorizing the transfer, and having its allowance consumed during the transfer.
  • from - The address holding the balance of tokens which will be withdrawn from.
  • to - The address which will receive the transferred tokens.
  • amount - The amount of tokens to be transferred.
Events

Emits an event with topics ["transfer", from: Address, to: Address], data = amount: i128

Source

impl TokenFnSpec

pub const fn spec_xdr_burn() -> [u8; 416]

Burn amount from from.

Reduces from’s balance by the amount, without transferring the balance to another holder’s balance.

Arguments
  • from - The address holding the balance of tokens which will be burned from.
  • amount - The amount of tokens to be burned.
Events

Emits an event with topics ["burn", from: Address], data = amount: i128

Source

impl TokenFnSpec

pub const fn spec_xdr_burn_from() -> [u8; 820]

Burn amount from from, consuming the allowance of spender.

Reduces from’s balance by the amount, without transferring the balance to another holder’s balance.

The spender will be allowed to burn the amount from from’s balance, if the amount is less than or equal to the allowance that the spender has on the from’s balance. The spender’s allowance on from’s balance will be reduced by the amount.

Arguments
  • spender - The address authorizing the burn, and having its allowance consumed during the burn.
  • from - The address holding the balance of tokens which will be burned from.
  • amount - The amount of tokens to be burned.
Events

Emits an event with topics ["burn", from: Address], data = amount: i128

Source

impl TokenFnSpec

pub const fn spec_xdr_decimals() -> [u8; 160]

Returns the number of decimals used to represent amounts of this token.

Panics

If the contract has not yet been initialized.

Source

impl TokenFnSpec

pub const fn spec_xdr_name() -> [u8; 120]

Returns the name for this token.

Panics

If the contract has not yet been initialized.

Source

impl TokenFnSpec

pub const fn spec_xdr_symbol() -> [u8; 124]

Returns the symbol for this token.

Panics

If the contract has not yet been initialized.