Crate stellar_axelar_std

Modules

address
error
events
traits
ttl
types

Macros

assert_auth
Assert that a contract call with authentication succeeds
assert_auth_err
assert_contract_err
Assert that a Result from a contract call is Err and matches an error variant
assert_err
Assert that a Result is Err and matches an error variant
assert_ok
Assert that a Result is Ok
assert_some
Assert that an Option is Some
ensure
Return with an error if a condition is not met.
mock_auth