pub struct BytesN<const N: usize>(/* private fields */);Expand description
BytesN is a contiguous fixed-size array type containing u8s.
The array is stored in the Host and available to the Guest through the functions defined on Bytes.
Bytes values can be stored as [Storage], or in other types like Vec, [Map], etc.
Examples
BytesN values can be created from arrays:
use soroban_sdk::{Bytes, BytesN, Env};
let env = Env::default();
let bytes = BytesN::from_array(&env, &[0; 32]);
assert_eq!(bytes.len(), 32);BytesN and Bytes values are convertible:
use soroban_sdk::{Bytes, BytesN, Env};
let env = Env::default();
let bytes = Bytes::from_slice(&env, &[0; 32]);
let bytes: BytesN<32> = bytes.try_into().expect("bytes to have length 32");
assert_eq!(bytes.len(), 32);Implementations
Sourceimpl<const N: usize> BytesN<N>
impl<const N: usize> BytesN<N>
pub fn env(&self) -> &Env
pub fn as_bytes(&self) -> &Bytes
pub fn into_bytes(self) -> Bytes
pub fn to_bytes(&self) -> Bytes
pub fn as_val(&self) -> &Val
pub fn to_val(&self) -> Val
pub fn as_object(&self) -> &BytesObject
pub fn to_object(&self) -> BytesObject
Sourcepub fn get(&self, i: u32) -> Option<u8>
pub fn get(&self, i: u32) -> Option<u8>
Returns the byte at the position or None if out-of-bounds.
Sourcepub fn get_unchecked(&self, i: u32) -> u8
pub fn get_unchecked(&self, i: u32) -> u8
Sourcepub fn first_unchecked(&self) -> u8
pub fn first_unchecked(&self) -> u8
Sourcepub fn last_unchecked(&self) -> u8
pub fn last_unchecked(&self) -> u8
Sourcepub fn copy_into_slice(&self, slice: &mut [u8; N])
pub fn copy_into_slice(&self, slice: &mut [u8; N])
Copy the bytes into the given slice.
pub fn iter(&self) -> BytesIter